@@ -47,6 +47,7 @@ class NextPictureManager:
         cur_pic: PictureData = self.sample_list[self.cur_pic_num]
         self.cur_pic_num += 1
         if os.path.exists(cur_pic.absolute_path):
+            self._inc_times_shown(cur_pic)
             return cur_pic
         else:
             return self.get_next_picture()
@@ -102,6 +103,10 @@ class NextPictureManager:
             .value,
             LAST_DB_UPDATE_FMT_STR,
         )
+        log.debug(
+            f"Last update in NextPicture manager = {self.last_db_update} and "
+            f"last update of db = {last_db_update}"
+        )
         if self.last_db_update < last_db_update:
             q = session.query(PictureData)
             if FILTER_RATING_BELOW in self.filters:
@@ -111,6 +116,7 @@ class NextPictureManager:
             full_picture_list = q.all()
             log.info(f"{len(full_picture_list)} pictures loaded.")
             session.close()
+            self.last_db_update = last_db_update
             return full_picture_list
         else:
             return None
