@@ -7,10 +7,12 @@ from pipictureframe.picdb.PictureUpdater import PictureData
 from pipictureframe.picdb.Database import LAST_DB_UPDATE_FMT_STR
 
 
-def get_config_mock():
+def get_config_mock(shuffle=False, shuffle_weight=0):
     config = Mock()
     config.shuffle = PropertyMock()
-    config.shuffle = False
+    config.shuffle = shuffle
+    config.shuffle_weight = PropertyMock()
+    config.shuffle_weight = shuffle_weight
     config.min_rating = PropertyMock()
     config.min_rating = None
     config.max_rating = PropertyMock()
